@@ -10,9 +10,11 @@ from .constants import DEFAULT_IND
 from .utils import indent_text, upper_sql_keywords
 from .constants import SECTIONS_WITH_COMMA_SEPARATOR, SQL_KEYWORDS
 from .sql_container import SqlContainer
+from .utils.classes.string_convertible import StringConvertible
+from .utils.classes.container_convertible import ContainerConvertible
 
 
-class SqlSection:
+class SqlSection(StringConvertible, ContainerConvertible):
     """SqlSection is invented to build one SQL block of query and put the result of
     this process to self.container which is SqlContainer instance.
     SQL block is build of:
@@ -21,7 +23,7 @@ class SqlSection:
             *statements provided in self.__call__ method.
     """
 
-    def __init__(self, header: str = ''):
+    def __init__(self, header: str | StringConvertible = ''):
         """Constract SqlSection instance.
         Params:
             - header: str - could be any string (empty is also possible).
@@ -45,7 +47,7 @@ class SqlSection:
         sep: Optional[str] = None,
         line_end: str = '\n',
         section_end: str = '',
-        ind: int = DEFAULT_IND,  # indentation
+        ind: int = 0,  # indentation
         upper_keywords: bool = True,
     ) -> SqlContainer:
         """Process building SQL block and put result to self.container and return latter.
@@ -66,14 +68,14 @@ class SqlSection:
             sep
             if sep is not None
             else ','
-            if self.header.upper() in SECTIONS_WITH_COMMA_SEPARATOR
+            if self.header.strip().upper() in SECTIONS_WITH_COMMA_SEPARATOR
             else ''
         )
         delimiter = sep + line_end
 
         section_body = delimiter.join(
             # if self.section_name == '' then do not indent
-            indent_text.indent_lines(str(x), ind=ind) if self.header else str(x)
+            indent_text.indent_lines(str(x), ind=ind + DEFAULT_IND) if self.header else str(x)
             for x in statements
             if x
         )
@@ -86,7 +88,9 @@ class SqlSection:
 
         sql_block = ''
         if self.header:
-            sql_block += self.header + '\n'
+            sql_block += indent_text.indent_lines(str(self.header), ind=ind)
+            if section_body:
+                sql_block += '\n'
         sql_block += section_body + section_end
 
         if upper_keywords:
