@@ -5,7 +5,7 @@ Module of Containerable class.
 
 __author__ = 'https://github.com/akvilary'
 
-from sqlconstructor import sql_container as sc
+from sqlconstructor import sql_container as s_c
 
 
 class ContainerConvertible:
@@ -14,7 +14,7 @@ class ContainerConvertible:
     to convert subclass instance to SqlContainer.
     """
     def __call__(self, container = None, /, **kwargs):
-        container = container if container is not None else sc.SqlContainer(str(self))
+        container = container if container is not None else s_c.SqlContainer(str(self))
         # add vars to container
         if kwargs:
             container(**kwargs)
