@@ -14,14 +14,17 @@ def test_inline():
     )
 
 
+@pytest.mark.SqlWrap
+def test_inline_and_unwrap():
+    container = SqlWrap('a').inline()
+    assert str(container) == '(a)'
+    assert str(container.unwrap()) == 'a'
+
+
 @pytest.mark.SqlWrap
 def test_inline_with_wrapper_text():
-    assert (
-        str(
-            SqlWrap(
-                'a',
-                'as b',
-            ).inline()
-        )
-        == '(a) as b'
-    )
+    container = SqlWrap(
+        'a',
+        'as b',
+    ).inline()
+    assert str(container) == '(a) as b'
